#!/bin/bash

# settings (adjust as needed)
N_WORKERS=1 # set based on number of available cores/memory, set to 1 for serial execution
SKIP_SUPPLEMENT=0 # set to 1 to skip replicating results from supplemental material
SKIP_PAPER=0 # set to 1 to skip replicating results from paper
export SKIP_ALTERNATIVE_TESTS=0 # set to 1 to skip alternative tests in replication


echo "========================================"
echo "Setup"
echo "========================================"

# check if Julia is installed and can be executed
if ! command -v julia &> /dev/null
then
echo "julia could not be found. Please make sure that julia is installed."
exit 1
fi

# install required julia packages
echo "installing required julia packages..."
cat <<EOF | julia
using Pkg
Pkg.update()
Pkg.add(["DelimitedFiles", "SpecialFunctions", "StaticArrays", "SparseArrays", "Statistics", "LinearAlgebra", "StatsBase", "StatsFuns", "Distributions", 
"ForwardDiff", "NLopt", "DataFrames", "CSV", "ProgressMeter", "LaTeXStrings"])
EOF
echo "julia packages installed successfully."


printf "\n"
echo "========================================"
echo "Paper"
echo "========================================"

if [[ $SKIP_PAPER -lt 1 ]]
then
printf "\nReplicating paper...\n"
printf "\n"
julia -t $N_WORKERS,1 scripts/Table2.jl
printf "\n"
julia -t $N_WORKERS,1 scripts/Table3.jl
printf "\n"
julia -t $N_WORKERS,1 scripts/Figure1.jl
printf "\n"
julia scripts/Figure2_3_S5.jl
printf "\n"
julia scripts/Figure4_5_S6.jl
printf "\n"
else
printf "Skipping replication of paper.\n"
fi


printf "\n"
echo "========================================"
echo "Supplement"
echo "========================================"

if [[ $SKIP_SUPPLEMENT -lt 1 ]]
then
printf "\nReplicating supplement...\n"
printf "\n"
julia -t $N_WORKERS,1 scripts/TableS1.jl
printf "\n"
julia -t $N_WORKERS,1 scripts/TableS2.jl
printf "\n"
julia -t $N_WORKERS,1 scripts/TableS3.jl
printf "\n"
julia -t $N_WORKERS,1 scripts/TableS4.jl
printf "\n"
julia -t $N_WORKERS,1 scripts/TableS5.jl
printf "\n"
julia -t $N_WORKERS,1 scripts/FigureS1_S2.jl
printf "\n"
julia scripts/FigureS3_S4.jl
printf "\n"
else
printf "Skipping replication of supplemental material.\n"
fi
