#---
# Helper script to run simulations (in parallel)
#---

using Printf, ProgressMeter

function ResultsWriter(nJobs::Int64, nThreads::Int64, ResultsFile::String, ResultHeader::String, resultsChannel::Channel)
    # create output file
    io = open(@sprintf("%s/../output/%s", string(Base.@__DIR__), ResultsFile), "w")
    write(io, @sprintf("%s\n", ResultHeader))
    close(io)
    
    # process incoming results
    io = open(@sprintf("%s/../output/%s", string(Base.@__DIR__), ResultsFile), "a")
    p = Progress(nJobs, .5, @sprintf("%s [%d threads]: ", ResultsFile, nThreads))
    s = 0
    while s<nJobs
        result = take!(resultsChannel)
        write(io, @sprintf("%s", format_csv(result)))
        flush(io)
        next!(p)
        s += 1
    end
end

function RunSimulation(ResultsFile::String)
    nThreads = Threads.nthreads()
    jobs = create_jobs() # create list of jobs
    
    # set up channels
    nJobs = length(jobs)
    jobsChannel = Channel{Job}(nJobs) # channel to feed jobs to parallel threads
    resultsChannel = Channel{Result}(nJobs) # channel to feed back results

    # start results writer
    writer = @async ResultsWriter(nJobs, nThreads, ResultsFile, ResultHeader, resultsChannel)
    
    # publish jobs to job channel
    for job in jobs; put!(jobsChannel, job); end

    # start remote workers
    Threads.@threads for i in 1:nJobs
        job = take!(jobsChannel)
        result = run_job(job)
        put!(resultsChannel, result)
    end

    wait(writer)
end
