#---
# Settings for Finite Sample simulations & empirical studies
#---

using Distributions, LinearAlgebra, Random, Printf

# general simulation settings
global SIM_LEVEL = 0.05
global SIM_JOB_SEED = 98345 # seed to set before starting a new simulation spec
global SIM_DISTS = ["N(0,1)", "t(15)", "t(10)", "t(5)", "SKU", "KU", "BM", "SPB", "SKB", "TRI"]
global SIM_MC_REPS = 2500
global SIM_MC_REPS_SMALL = 1000
global SIM_BS_REPS = 500 # for DW test
global SIM_BURNIN = 400
global SIM_CONSTANT = false

# empirical studies settings
global EMP_GRID_FACTOR = 50

# splines settings
global SIM_SPLINES_B = 7
global SIM_SPLINES_CUTOFF = 0.01

# structural parameters α0
global SIM_αs_euler = Dict( 2 => [π/5], 3 => [3*π/5, 2*π/5, -1*π/5]) # Euler angle parametrisation
α_vec = [0.5594, 0.7646, 0.1151, -0.5082, -1.271, 0.2536, 0.0061, -0.2297, -1.1795, -0.3591]
global SIM_αs_caley = Dict( 2 => [α_vec[1]], 3 => α_vec[1:3], 4 => α_vec[1:6], 5 => α_vec[1:10] ) # Cayley parameterization

# β₁ parameters of the SVAR
global SIM_β₁s = Dict( 
    2 => vech(cholesky( I(2) ).L),
    3 => vech(cholesky( I(3) ).L),
    4 => vech(cholesky( I(4) ).L),
    5 => vech(cholesky( I(5) ).L)
)

# β₂ parameters of the SVAR
global SIM_β₂s = Dict{AbstractVector,AbstractVector}()
for K ∈ [2, 3, 5], p ∈ [1, 2, 4, 12]
    local ϕs
    if p==1
        ϕs = [.9]
    elseif p==2
        ϕs = [1.1, -0.2]
    elseif p==4
        ϕs = [1.2, -0.6, 0.3, -0.1]
    elseif p==8
        ϕs = [0.14, 0.83, 0.25, -0.54, -0.38, 0.36, 0.03, -0.19]
    elseif p==12
        ϕs = [-0.0304, 1.0612, 0.636, -0.829, -1.0771, 0.5795, 0.9112, -0.0585, -0.8153, -0.3159, 0.3918, 0.107]
    end
    SIM_β₂s[[K,p]] = vec( mapreduce(p-> p * I(K), hcat, ϕs) )
end
